Configuration Methods — Rucio 1.2 documentation

# Configuration Methods

class `rucio.client.configclient.` `ConfigClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Client class for working with the configuration

  `CONFIG_BASEURL` = 'config'
  `delete_config_option`(section, option)

    Sends the request to remove an option from a section

    Parameters: | section – the name of the section. option – the name of the option.
    Returns: | True if option was removed successfully. False otherwise.

  `get_config`(section=None, option=None)

    Sends the request to get the matching configuration.

    Parameters: | section – the optional name of the section. option – the optional option within the section.
    Returns: | dictionary containing the configuration.

  `set_config_option`(section, option, value)

    Sends the request to create or set an option within a section. Missing sections will be created.

    Parameters: | section – the name of the section. option – the name of the option.
    Returns: | True if option was removed successfully. False otherwise.